Module init

Module init 

Structs

InitArgs
LegacyWorkspace
The workspace init was pointed at is one this build will not write into.

Functions

fragment
The [[client]] slice init prints for spec.toml.
init
legacy_error_code
toml_string
One TOML basic string, with the characters a basic string cannot hold escaped.