pub struct ReadyNotice {
pub task_id: String,
pub session_id: String,
pub generation: u64,
pub io: Option<AdapterIo>,
pub capabilities: Vec<Capability>,
}Expand description
Adapter facts that make a session usable for its task.
Fields
task_id: Stringsession_id: Stringgeneration: u64io: Option<AdapterIo>Adapter transport for plugin-driven backends. A self-driven backend owns its agent and therefore reports ready without a socket.
capabilities: Vec<Capability>Auto Trait Implementations
impl !RefUnwindSafe for ReadyNotice
impl !UnwindSafe for ReadyNotice
impl Freeze for ReadyNotice
impl Send for ReadyNotice
impl Sync for ReadyNotice
impl Unpin for ReadyNotice
impl UnsafeUnpin for ReadyNotice